Package: MNP
Version: 3.1-5
Title: Fitting the Multinomial Probit Model
Authors@R: c(
  person("Kosuke", "Imai", , "imai@harvard.edu", c("aut", "cre")),
  person("David", "van Dyk", , "dvandyk@imperial.ac.uk", c("aut")),
  person("Hubert", "Jin", , "hubertj@princeton.edu", c("ctb"))
  )
Maintainer: Kosuke Imai <imai@harvard.edu>
Depends: R (>= 2.1), stats, utils
Suggests: testthat
Description: Fits the Bayesian multinomial probit model via Markov chain
 Monte Carlo.  The multinomial probit model is often used to analyze 
 the discrete choices made by individuals recorded in survey data. 
 Examples where the multinomial probit model may be useful include the 
 analysis of product choice by consumers in market research and the 
 analysis of candidate or party choice by voters in electoral studies.  
 The MNP package can also fit the model with different choice sets for 
 each individual, and complete or partial individual choice orderings 
 of the available alternatives from the choice set. The estimation is
 based on the efficient marginal data augmentation algorithm that is 
 developed by Imai and van Dyk (2005). "A Bayesian Analysis of the 
 Multinomial Probit Model Using the Data Augmentation." Journal of 
 Econometrics, Vol. 124, No. 2 (February), pp. 311-334. 
 <doi:10.1016/j.jeconom.2004.02.002>  Detailed examples are given in 
 Imai and van Dyk (2005). "MNP: R Package for Fitting the Multinomial 
 Probit Model."  Journal of Statistical Software, Vol. 14, No. 3 (May), 
 pp. 1-32. <doi:10.18637/jss.v014.i03>.
LazyLoad: yes
LazyData: yes
License: GPL (>= 2)
Encoding: UTF-8
URL: https://github.com/kosukeimai/MNP
BugReports: https://github.com/kosukeimai/MNP/issues
NeedsCompilation: yes
RoxygenNote: 7.3.1
Packaged: 2024-06-20 02:44:05 UTC; kosukeimai
Author: Kosuke Imai [aut, cre],
  David van Dyk [aut],
  Hubert Jin [ctb]
Repository: CRAN
Date/Publication: 2024-06-20 10:20:25 UTC
